Skip to contents

Format a .csv transaction history file from the Exodus wallet for later ACB processing.

Usage

format_exodus(data, list.prices = NULL, force = FALSE)

Arguments

data

The dataframe

list.prices

An optional explicit list.prices object from which to fetch coin prices. For exchanges that require external pricing, it must contain at least currency, spot.rate2, and date2.

force

Whether to force recreating list.prices even though it already exists (e.g., if you added new coins or new dates).

Value

A data frame of exchange transactions, formatted for further processing.

Examples

# \donttest{
format_exodus(data_exodus)
#> Using cached 'list.prices'. To force a fresh download, use argument 'force = TRUE'.
#>                  date currency  quantity total.price spot.rate transaction
#> 1 2021-05-25 22:06:11      LTC 0.0014430          NA        NA        sell
#> 2 2021-05-25 23:08:12      ADA 0.1782410          NA        NA        sell
#> 3 2021-06-12 12:15:28      BTC 0.0000503    2.227033     44275        sell
#> 4 2021-06-12 22:31:35      ETH 0.0014500          NA        NA        sell
#>   description revenue.type exchange   rate.source
#> 1  withdrawal         <NA>   exodus coinmarketcap
#> 2  withdrawal         <NA>   exodus coinmarketcap
#> 3  withdrawal         <NA>   exodus coinmarketcap
#> 4  withdrawal         <NA>   exodus coinmarketcap
# }