Learn R Programming

cryptoTax (version 0.0.5)

get_latest_transactions: Get the date from the latest transactions per exchange

Description

Get the date from the latest transactions per exchange

Usage

get_latest_transactions(formatted.ACB)

Value

A data frame with two columns: the name of the exchange as well as the date of the latest transaction.

Arguments

formatted.ACB

The formatted.ACB file

Examples

Run this code
all.data <- format_shakepay(data_shakepay)
formatted.ACB <- format_ACB(all.data, verbose = FALSE)
get_latest_transactions(formatted.ACB)

Run the code above in your browser using DataLab