powered by
Format numeric values with comma for thousands separator. Can be converted back from this format to numeric using to = "numeric".
to = "numeric"
format_dollars(x, to = "character")
A value representing dollars, either as a formatted character string or as a numeric value.
The formatted.ACB file
What to convert to, with otions c("character", "numeric").
c("character", "numeric")
x <- format_dollars(1010.92) x format_dollars(x, to = "numeric")
Run the code above in your browser using DataLab