Learn R Programming

cryptoTax (version 0.0.5)

format_newton: Format Newton file

Description

Format a .csv transaction history file from Newton for later ACB processing. When downloading from Newton, please choose the yearly reports format (the "CoinTracker Version" and "Koinly Version" are not supported at this time). If you have multiple years, that means you might have to merge the two datasets.

Usage

format_newton(data, filetype = "yearly")

Value

A data frame of exchange transactions, formatted for further processing.

Arguments

data

The dataframe

filetype

Which Newton file format to use, one of c("yearly", "cointracker", or "koinly"). Only "yearly" (default) supported at this time.

Examples

Run this code
format_newton(data_newton)

Run the code above in your browser using DataLab