powered by
Get the date from the latest transactions per exchange
get_latest_transactions(formatted.ACB)
A data frame with two columns: the name of the exchange as well as the date of the latest transaction.
The formatted.ACB file
all.data <- format_shakepay(data_shakepay) formatted.ACB <- format_ACB(all.data, verbose = FALSE) get_latest_transactions(formatted.ACB)
Run the code above in your browser using DataLab