Learn R Programming

cryptoTax (version 0.0.5)

print_report: Print full crypto tax report

Description

Will output a full crypto tax report in HTML format, which can then be printed or saved as PDF.

Usage

print_report(tax.year, name, report.info)

Value

An HTML page containing a crypto tax report.

Arguments

tax.year

The tax year desired.

name

Name of the individual for the report.

report.info

The report info obtained from prepare_report().

Examples

Run this code
# \donttest{
list.prices <- prepare_list_prices(coins = "BTC", start.date = "2021-01-01")
all.data <- format_shakepay(data_shakepay)
formatted.ACB <- format_ACB(all.data, verbose = FALSE)
report.info <- prepare_report(formatted.ACB, 2021, list.prices = list.prices)
print_report(2021, "Mr. Cryptoltruist", report.info)
# }
# \dontshow{
unlink("full_report.html")
# }

Run the code above in your browser using DataLab