powered by
Provides a summary of realized capital gains and losses (and total).
report_summary( formatted.ACB, today.data = TRUE, tax.year = "all", local.timezone = Sys.timezone(), list.prices = NULL, force = FALSE )
A summary data frame, containing at least the following columns: Type, Amount, currency.
The formatted ACB data.
whether to fetch today's data.
Which tax year(s) to include.
Which time zone to use for the date of the report.
A list.prices object from which to fetch coin prices.
list.prices
Whether to force recreating list.prices even though it already exists (e.g., if you added new coins or new dates).
all.data <- format_shakepay(data_shakepay) formatted.ACB <- format_ACB(all.data, verbose = FALSE) report_summary(formatted.ACB, today.data = FALSE)
Run the code above in your browser using DataLab